<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 9/22/2008	ELL
// Added text shadow effects.
// Revised: 1/9/2011	ELL
// Added capability to handle multiple JavaScript Menus.
// Revised: 2/10/2012	ELL
// Added table prefix handling.  Added references to script folder configuration.
// Revised: 2/10/2013	ELL
// Fixed bug of underline being present even when not selected.
	
	include ("check_session.php");

	$submit = $_POST['submit'];
	$menu = $_POST['menu'];
	$suffix = substr($menu, 4);
	
	include ("build_sql_string.php");
	
	if ($submit == "Preview")
	{
		$site_css_table = "menu_styles_preview";
		$css_file = "menu_preview.css";
		
		$query = "TRUNCATE TABLE " . BWB_TABLE_PREFIX . "menu_styles_preview";
		$cnt = $bwb_dbh->exec($query);
	}
	else
	{
		$site_css_table = $menu . "_css";
		$css_file = $menu . ".css";
	}
	
	$top_level_font_out = $_POST['top_level_font_out'];
	$top_level_font_size_out = $_POST['top_level_font_size_out'];
	$top_level_text_color_out = $_POST['top_level_text_color_out'];
	$top_level_padding_out = $_POST['top_level_padding_out'];
	$top_level_bold_out = $_POST['top_level_bold_out'];
	$top_level_italic_out = isset($_POST['top_level_italic_out']) ? 1 : 0;
	$top_level_underline_out = isset($_POST['top_level_underline_out']) ? 1 : 0;
	$top_level_overline_out = isset($_POST['top_level_overline_out']) ? 1 : 0;
	$top_level_blink_out = isset($_POST['top_level_blink_out']) ? 1 : 0;
	
	$top_level_shadow_out = isset($_POST['top_level_shadow_out']) ? 1 : 0;
	$top_level_shadow_color_out = isset($_POST['top_level_shadow_color_out']) ? $_POST['top_level_shadow_color_out'] : "-none-";
	$top_level_shadow_x_offset_out = isset($_POST['top_level_shadow_x_offset_out']) ? $_POST['top_level_shadow_x_offset_out'] : 0;
	$top_level_shadow_y_offset_out = isset($_POST['top_level_shadow_y_offset_out']) ? $_POST['top_level_shadow_y_offset_out'] : 0;
	$top_level_shadow_blur_out = isset($_POST['top_level_shadow_blur_out']) ? $_POST['top_level_shadow_blur_out'] : 0;
	
	$top_level_font_over = $_POST['top_level_font_over'];
	$top_level_font_size_over = $_POST['top_level_font_size_over'];
	$top_level_text_color_over = $_POST['top_level_text_color_over'];
	$top_level_padding_over = $_POST['top_level_padding_over'];
	$top_level_bold_over = $_POST['top_level_bold_over'];
	$top_level_italic_over = isset($_POST['top_level_italic_over']) ? 1 : 0;
	$top_level_underline_over = isset($_POST['top_level_underline_over']) ? 1 : 0;
	$top_level_overline_over = isset($_POST['top_level_overline_over']) ? 1 : 0;
	$top_level_blink_over = isset($_POST['top_level_blink_over']) ? 1 : 0;
	
	$top_level_shadow_over = isset($_POST['top_level_shadow_over']) ? 1 : 0;
	$top_level_shadow_color_over = isset($_POST['top_level_shadow_color_over']) ? $_POST['top_level_shadow_color_over'] : "-none-";
	$top_level_shadow_x_offset_over = isset($_POST['top_level_shadow_x_offset_over']) ? $_POST['top_level_shadow_x_offset_over'] : 0;
	$top_level_shadow_y_offset_over = isset($_POST['top_level_shadow_y_offset_over']) ? $_POST['top_level_shadow_y_offset_over'] : 0;
	$top_level_shadow_blur_over = isset($_POST['top_level_shadow_blur_over']) ? $_POST['top_level_shadow_blur_over'] : 0;
	
	$top_level_bkgd_color_out = $_POST['top_level_bkgd_color_out'];
	$top_level_bkgd_opacity_out = $_POST['top_level_bkgd_opacity_out'];
	$top_level_border_out = $_POST['top_level_border_out'];
	$top_level_border_color_out = $_POST['top_level_border_color_out'];
	$top_level_bkgd_color_over = $_POST['top_level_bkgd_color_over'];
	$top_level_border_over = $_POST['top_level_border_over'];
	$top_level_border_color_over = $_POST['top_level_border_color_over'];
	$sub_level_1_font_out = $_POST['sub_level_1_font_out'];
	$sub_level_1_font_size_out = $_POST['sub_level_1_font_size_out'];
	$sub_level_1_text_color_out = $_POST['sub_level_1_text_color_out'];
	$sub_level_1_padding_out = $_POST['sub_level_1_padding_out'];
	$sub_level_1_bold_out = $_POST['sub_level_1_bold_out'];
	$sub_level_1_italic_out = isset($_POST['sub_level_1_italic_out']) ? 1 : 0;
	$sub_level_1_underline_out = isset($_POST['sub_level_1_underline_out']) ? 1 : 0;
	$sub_level_1_overline_out = isset($_POST['sub_level_1_overline_out']) ? 1 : 0;
	$sub_level_1_blink_out = isset($_POST['sub_level_1_blink_out']) ? 1 : 0;
	
	$sub_level_1_shadow_out = isset($_POST['sub_level_1_shadow_out']) ? 1 : 0;
	$sub_level_1_shadow_color_out = isset($_POST['sub_level_1_shadow_color_out']) ? $_POST['sub_level_1_shadow_color_out'] : "-none-";
	$sub_level_1_shadow_x_offset_out = isset($_POST['sub_level_1_shadow_x_offset_out']) ? $_POST['sub_level_1_shadow_x_offset_out'] : 0;
	$sub_level_1_shadow_y_offset_out = isset($_POST['sub_level_1_shadow_y_offset_out']) ? $_POST['sub_level_1_shadow_y_offset_out'] : 0;
	$sub_level_1_shadow_blur_out = isset($_POST['sub_level_1_shadow_blur_out']) ? $_POST['sub_level_1_shadow_blur_out'] : 0;
	
	$sub_level_1_font_over = $_POST['sub_level_1_font_over'];
	$sub_level_1_font_size_over = $_POST['sub_level_1_font_size_over'];
	$sub_level_1_text_color_over = $_POST['sub_level_1_text_color_over'];
	$sub_level_1_padding_over = $_POST['sub_level_1_padding_over'];
	$sub_level_1_bold_over = $_POST['sub_level_1_bold_over'];
	$sub_level_1_italic_over = isset($_POST['sub_level_1_italic_over']) ? 1 : 0;
	$sub_level_1_underline_over = isset($_POST['sub_level_1_underline_over']) ? 1 : 0;
	$sub_level_1_overline_over = isset($_POST['sub_level_1_overline_over']) ? 1 : 0;
	$sub_level_1_blink_over = isset($_POST['sub_level_1_blink_over']) ? 1 : 0;
	
	$sub_level_1_shadow_over = isset($_POST['sub_level_1_shadow_over']) ? 1 : 0;
	$sub_level_1_shadow_color_over = isset($_POST['sub_level_1_shadow_color_over']) ? $_POST['sub_level_1_shadow_color_over'] : "-none-";
	$sub_level_1_shadow_x_offset_over = isset($_POST['sub_level_1_shadow_x_offset_over']) ? $_POST['sub_level_1_shadow_x_offset_over'] : 0;
	$sub_level_1_shadow_y_offset_over = isset($_POST['sub_level_1_shadow_y_offset_over']) ? $_POST['sub_level_1_shadow_y_offset_over'] : 0;
	$sub_level_1_shadow_blur_over = isset($_POST['sub_level_1_shadow_blur_over']) ? $_POST['sub_level_1_shadow_blur_over'] : 0;
	
	$sub_level_1_bkgd_color_out = $_POST['sub_level_1_bkgd_color_out'];
	$sub_level_1_bkgd_opacity_out = $_POST['sub_level_1_bkgd_opacity_out'];
	$sub_level_1_border_out = $_POST['sub_level_1_border_out'];
	$sub_level_1_border_color_out = $_POST['sub_level_1_border_color_out'];
	$sub_level_1_bkgd_color_over = $_POST['sub_level_1_bkgd_color_over'];
	$sub_level_1_border_over = $_POST['sub_level_1_border_over'];
	$sub_level_1_border_color_over = $_POST['sub_level_1_border_color_over'];
	$sub_level_2_font_out = $_POST['sub_level_2_font_out'];
	$sub_level_2_font_size_out = $_POST['sub_level_2_font_size_out'];
	$sub_level_2_text_color_out = $_POST['sub_level_2_text_color_out'];
	$sub_level_2_padding_out = $_POST['sub_level_2_padding_out'];
	$sub_level_2_bold_out = $_POST['sub_level_2_bold_out'];
	$sub_level_2_italic_out = isset($_POST['sub_level_2_italic_out']) ? 1 : 0;
	$sub_level_2_underline_out = isset($_POST['sub_level_2_underline_out']) ? 1 : 0;
	$sub_level_2_overline_out = isset($_POST['sub_level_2_overline_out']) ? 1 : 0;
	$sub_level_2_blink_out = isset($_POST['sub_level_2_blink_out']) ? 1 : 0;
	
	$sub_level_2_shadow_out = isset($_POST['sub_level_2_shadow_out']) ? 1 : 0;
	$sub_level_2_shadow_color_out = isset($_POST['sub_level_2_shadow_color_out']) ? $_POST['sub_level_2_shadow_color_out'] : "-none-";
	$sub_level_2_shadow_x_offset_out = isset($_POST['sub_level_2_shadow_x_offset_out']) ? $_POST['sub_level_2_shadow_x_offset_out'] : 0;
	$sub_level_2_shadow_y_offset_out = isset($_POST['sub_level_2_shadow_y_offset_out']) ? $_POST['sub_level_2_shadow_y_offset_out'] : 0;
	$sub_level_2_shadow_blur_out = isset($_POST['sub_level_2_shadow_blur_out']) ? $_POST['sub_level_2_shadow_blur_out'] : 0;
	
	$sub_level_2_font_over = $_POST['sub_level_2_font_over'];
	$sub_level_2_font_size_over = $_POST['sub_level_2_font_size_over'];
	$sub_level_2_text_color_over = $_POST['sub_level_2_text_color_over'];
	$sub_level_2_padding_over = $_POST['sub_level_2_padding_over'];
	$sub_level_2_bold_over = $_POST['sub_level_2_bold_over'];
	$sub_level_2_italic_over = isset($_POST['sub_level_2_italic_over']) ? 1 : 0;
	$sub_level_2_underline_over = isset($_POST['sub_level_2_underline_over']) ? 1 : 0;
	$sub_level_2_overline_over = isset($_POST['sub_level_2_overline_over']) ? 1 : 0;
	$sub_level_2_blink_over = isset($_POST['sub_level_2_blink_over']) ? 1 : 0;
	
	$sub_level_2_shadow_over = isset($_POST['sub_level_2_shadow_over']) ? 1 : 0;
	$sub_level_2_shadow_color_over = isset($_POST['sub_level_2_shadow_color_over']) ? $_POST['sub_level_2_shadow_color_over'] : "-none-";
	$sub_level_2_shadow_x_offset_over = isset($_POST['sub_level_2_shadow_x_offset_over']) ? $_POST['sub_level_2_shadow_x_offset_over'] : 0;
	$sub_level_2_shadow_y_offset_over = isset($_POST['sub_level_2_shadow_y_offset_over']) ? $_POST['sub_level_2_shadow_y_offset_over'] : 0;
	$sub_level_2_shadow_blur_over = isset($_POST['sub_level_2_shadow_blur_over']) ? $_POST['sub_level_2_shadow_blur_over'] : 0;
	
	$sub_level_2_bkgd_color_out = $_POST['sub_level_2_bkgd_color_out'];
	$sub_level_2_bkgd_opacity_out = $_POST['sub_level_2_bkgd_opacity_out'];
	$sub_level_2_border_out = $_POST['sub_level_2_border_out'];
	$sub_level_2_border_color_out = $_POST['sub_level_2_border_color_out'];
	$sub_level_2_bkgd_color_over = $_POST['sub_level_2_bkgd_color_over'];
	$sub_level_2_border_over = $_POST['sub_level_2_border_over'];
	$sub_level_2_border_color_over = $_POST['sub_level_2_border_color_over'];
		
	/////////////////////////////////////////////////////////////////
	if (($top_level_underline_out == 0) && ($top_level_overline_out == 0) && ($top_level_blink_out == 0))
		$top_level_no_text_dec_out = 1;
	else
		$top_level_no_text_dec_out = 0;
		
	if (($top_level_underline_over == 0) && ($top_level_overline_over == 0) && ($top_level_blink_over == 0))
		$top_level_no_text_dec_over = 1;
	else
		$top_level_no_text_dec_over = 0;
		
	if (($sub_level_1_underline_over == 0) && ($sub_level_1_overline_over == 0) && ($sub_level_1_blink_over == 0))
		$sub_level_1_no_text_dec_over = 1;
	else
		$sub_level_1_no_text_dec_over = 0;
		
	if (($sub_level_1_underline_out == 0) && ($sub_level_1_overline_out == 0) && ($sub_level_1_blink_out == 0))
		$sub_level_1_no_text_dec_out = 1;
	else
		$sub_level_1_no_text_dec_out = 0;
		
	if (($sub_level_2_underline_over == 0) && ($sub_level_2_overline_over == 0) && ($sub_level_2_blink_over == 0))
		$sub_level_2_no_text_dec_over = 1;
	else
		$sub_level_2_no_text_dec_over = 0;
		
	if (($sub_level_2_underline_out == 0) && ($sub_level_2_overline_out == 0) && ($sub_level_2_blink_out == 0))
		$sub_level_2_no_text_dec_out = 1;
	else
		$sub_level_2_no_text_dec_out = 0;
		
	////////////////////////////////////////////////////////////////////////
	if ($top_level_border_out > 0)
		$top_level_border_style_out = "solid";
	else
		$top_level_border_style_out = "-not selected-";
		
	if ($top_level_border_over > 0)
		$top_level_border_style_over = "solid";
	else
		$top_level_border_style_over = "-not selected-";
		
	if ($sub_level_1_border_out > 0)
		$sub_level_1_border_style_out = "solid";
	else
		$sub_level_1_border_style_out = "-not selected-";
		
	if ($sub_level_1_border_over > 0)
		$sub_level_1_border_style_over = "solid";
	else
		$sub_level_1_border_style_over = "-not selected-";
		
	if ($sub_level_2_border_out > 0)
		$sub_level_2_border_style_out = "solid";
	else
		$sub_level_2_border_style_out = "-not selected-";
		
	if ($sub_level_2_border_over > 0)
		$sub_level_2_border_style_over = "solid";
	else
		$sub_level_2_border_style_over = "-not selected-";
		
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l0iout" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l0iout" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, $top_level_font_out, $top_level_font_size_out, $top_level_text_color_out, $top_level_padding_out, $top_level_padding_out, $top_level_padding_out, $top_level_padding_out, $top_level_bold_out, $top_level_italic_out,
		 $top_level_underline_out, $top_level_overline_out, $top_level_blink_out, 0, "-not selected-", 0, 0, $top_level_no_text_dec_out, $top_level_shadow_out, $top_level_shadow_color_out, $top_level_shadow_x_offset_out,
		$top_level_shadow_y_offset_out, $top_level_shadow_blur_out, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l0iout" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, $top_level_font_out, $top_level_font_size_out, $top_level_text_color_out, $top_level_padding_out, $top_level_padding_out, $top_level_padding_out, $top_level_padding_out, $top_level_bold_out, $top_level_italic_out,
		 $top_level_underline_out, $top_level_overline_out, $top_level_blink_out, 0, "-not selected-", 0, 0, $top_level_no_text_dec_out, $top_level_shadow_out, $top_level_shadow_color_out, $top_level_shadow_x_offset_out,
		$top_level_shadow_y_offset_out, $top_level_shadow_blur_out, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l0iover" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l0iover" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, $top_level_font_over, $top_level_font_size_over, $top_level_text_color_over, $top_level_padding_over, $top_level_padding_over, $top_level_padding_over, $top_level_padding_over, $top_level_bold_over, $top_level_italic_over,
		 $top_level_underline_over, $top_level_overline_over, $top_level_blink_over, 0, "-not selected-", 0, 0, $top_level_no_text_dec_over, $top_level_shadow_over, $top_level_shadow_color_over, $top_level_shadow_x_offset_over,
		$top_level_shadow_y_offset_over, $top_level_shadow_blur_over, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l0iover" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, $top_level_font_over, $top_level_font_size_over, $top_level_text_color_over, $top_level_padding_over, $top_level_padding_over, $top_level_padding_over, $top_level_padding_over, $top_level_bold_over, $top_level_italic_over,
		 $top_level_underline_over, $top_level_overline_over, $top_level_blink_over, 0, "-not selected-", 0, 0, $top_level_no_text_dec_over, $top_level_shadow_over, $top_level_shadow_color_over, $top_level_shadow_x_offset_over,
		$top_level_shadow_y_offset_over, $top_level_shadow_blur_over, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l0oout" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l0oout" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $top_level_no_text_dec_out, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $top_level_bkgd_color_out, $top_level_bkgd_opacity_out, $top_level_border_out, $top_level_border_color_out,
		$top_level_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l0oout" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $top_level_no_text_dec_out, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $top_level_bkgd_color_out, $top_level_bkgd_opacity_out, $top_level_border_out, $top_level_border_color_out,
		$top_level_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l0oover" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l0oover" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $top_level_no_text_dec_over, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $top_level_bkgd_color_over, -1, $top_level_border_over, $top_level_border_color_over,
		$top_level_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l0oover" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $top_level_no_text_dec_over, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $top_level_bkgd_color_over, -1, $top_level_border_over, $top_level_border_color_over,
		$top_level_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l1iout" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l1iout" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, $sub_level_1_font_out, $sub_level_1_font_size_out, $sub_level_1_text_color_out, $sub_level_1_padding_out, $sub_level_1_padding_out, $sub_level_1_padding_out, $sub_level_1_padding_out, $sub_level_1_bold_out, $sub_level_1_italic_out,
		 $sub_level_1_underline_out, $sub_level_1_overline_out, $sub_level_1_blink_out, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_out, $sub_level_1_shadow_out, $sub_level_1_shadow_color_out, $sub_level_1_shadow_x_offset_out,
		$sub_level_1_shadow_y_offset_out, $sub_level_1_shadow_blur_out, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l1iout" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, $sub_level_1_font_out, $sub_level_1_font_size_out, $sub_level_1_text_color_out, $sub_level_1_padding_out, $sub_level_1_padding_out, $sub_level_1_padding_out, $sub_level_1_padding_out, $sub_level_1_bold_out, $sub_level_1_italic_out,
		 $sub_level_1_underline_out, $sub_level_1_overline_out, $sub_level_1_blink_out, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_out, $sub_level_1_shadow_out, $sub_level_1_shadow_color_out, $sub_level_1_shadow_x_offset_out,
		$sub_level_1_shadow_y_offset_out, $sub_level_1_shadow_blur_out, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l1iover" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l1iover" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, $sub_level_1_font_over, $sub_level_1_font_size_over, $sub_level_1_text_color_over, $sub_level_1_padding_over, $sub_level_1_padding_over, $sub_level_1_padding_over, $sub_level_1_padding_over, $sub_level_1_bold_over, $sub_level_1_italic_over,
		 $sub_level_1_underline_over, $sub_level_1_overline_over, $sub_level_1_blink_over, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_over, $sub_level_1_shadow_over, $sub_level_1_shadow_color_over, $sub_level_1_shadow_x_offset_over,
		$sub_level_1_shadow_y_offset_over, $sub_level_1_shadow_blur_over, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l1iover" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, $sub_level_1_font_over, $sub_level_1_font_size_over, $sub_level_1_text_color_over, $sub_level_1_padding_over, $sub_level_1_padding_over, $sub_level_1_padding_over, $sub_level_1_padding_over, $sub_level_1_bold_over, $sub_level_1_italic_over,
		 $sub_level_1_underline_over, $sub_level_1_overline_over, $sub_level_1_blink_over, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_over, $sub_level_1_shadow_over, $sub_level_1_shadow_color_over, $sub_level_1_shadow_x_offset_over,
		$sub_level_1_shadow_y_offset_over, $sub_level_1_shadow_blur_over, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l1oout" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l1oout" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_out, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_1_bkgd_color_out, $sub_level_1_bkgd_opacity_out, $sub_level_1_border_out, $sub_level_1_border_color_out,
		$sub_level_1_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l1oout" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_out, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_1_bkgd_color_out, $sub_level_1_bkgd_opacity_out, $sub_level_1_border_out, $sub_level_1_border_color_out,
		$sub_level_1_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l1oover" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l1oover" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_over, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_1_bkgd_color_over, -1, $sub_level_1_border_over, $sub_level_1_border_color_over,
		$sub_level_1_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l1oover" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_1_no_text_dec_over, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_1_bkgd_color_over, -1, $sub_level_1_border_over, $sub_level_1_border_color_over,
		$sub_level_1_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l2iout" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l2iout" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, $sub_level_2_font_out, $sub_level_2_font_size_out, $sub_level_2_text_color_out, $sub_level_2_padding_out, $sub_level_2_padding_out, $sub_level_2_padding_out, $sub_level_2_padding_out, $sub_level_2_bold_out, $sub_level_2_italic_out,
		 $sub_level_2_underline_out, $sub_level_2_overline_out, $sub_level_2_blink_out, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_out, $sub_level_2_shadow_out, $sub_level_2_shadow_color_out, $sub_level_2_shadow_x_offset_out,
		$sub_level_2_shadow_y_offset_out, $sub_level_2_shadow_blur_out, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l2iout" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, $sub_level_2_font_out, $sub_level_2_font_size_out, $sub_level_2_text_color_out, $sub_level_2_padding_out, $sub_level_2_padding_out, $sub_level_2_padding_out, $sub_level_2_padding_out, $sub_level_2_bold_out, $sub_level_2_italic_out,
		 $sub_level_2_underline_out, $sub_level_2_overline_out, $sub_level_2_blink_out, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_out, $sub_level_2_shadow_out, $sub_level_2_shadow_color_out, $sub_level_2_shadow_x_offset_out,
		$sub_level_2_shadow_y_offset_out, $sub_level_2_shadow_blur_out, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l2iover" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l2iover" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, $sub_level_2_font_over, $sub_level_2_font_size_over, $sub_level_2_text_color_over, $sub_level_2_padding_over, $sub_level_2_padding_over, $sub_level_2_padding_over, $sub_level_2_padding_over, $sub_level_2_bold_over, $sub_level_2_italic_over,
		 $sub_level_2_underline_over, $sub_level_2_overline_over, $sub_level_2_blink_over, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_over, $sub_level_2_shadow_over, $sub_level_2_shadow_color_over, $sub_level_2_shadow_x_offset_over,
		$sub_level_2_shadow_y_offset_over, $sub_level_2_shadow_blur_over, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l2iover" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, $sub_level_2_font_over, $sub_level_2_font_size_over, $sub_level_2_text_color_over, $sub_level_2_padding_over, $sub_level_2_padding_over, $sub_level_2_padding_over, $sub_level_2_padding_over, $sub_level_2_bold_over, $sub_level_2_italic_over,
		 $sub_level_2_underline_over, $sub_level_2_overline_over, $sub_level_2_blink_over, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_over, $sub_level_2_shadow_over, $sub_level_2_shadow_color_over, $sub_level_2_shadow_x_offset_over,
		$sub_level_2_shadow_y_offset_over, $sub_level_2_shadow_blur_over, -1, 0, "-not selected-", "-not selected-", "-not set-", -1, -1, "-not set-",
		"-not selected-", "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0,  "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l2oout" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l2oout" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_out, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_2_bkgd_color_out, $sub_level_2_bkgd_opacity_out, $sub_level_2_border_out, $sub_level_2_border_color_out,
		$sub_level_2_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l2oout" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_out, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_2_bkgd_color_out, $sub_level_2_bkgd_opacity_out, $sub_level_2_border_out, $sub_level_2_border_color_out,
		$sub_level_2_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	////////////////////////////////////////////////////////////////////////////////////////////////////////////
	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.m0l2oover" . $suffix . "'";
	$result = $bwb_dbh->query($query);
	$row_count = $result->rowCount();
		
	if ($row_count > 0)
	{
		//Update class record.
		$condition = "`class` = '.m0l2oover" . $suffix . "'";
		
		$query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "UPDATE", $condition, "", 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_over, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_2_bkgd_color_over, -1, $sub_level_2_border_over, $sub_level_2_border_color_over,
		$sub_level_2_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
	else
	{
		//Insert new data into table.
		$insert_key = "class='.m0l2oover" . $suffix . "', ";
		 
		 $query = BuildSQLString(BWB_TABLE_PREFIX . $site_css_table, "INSERT INTO", "", $insert_key, 1, "-not selected-", -1, "-not set-", -1, -1, -1, -1, "-not selected-", 0,
		0, 0, 0, 0, "-not selected-", 0, 0, $sub_level_2_no_text_dec_over, 0, "-not set-", 0,
		0, 0, -1, 0, "-not selected-", "-not selected-", $sub_level_2_bkgd_color_over, -1, $sub_level_2_border_over, $sub_level_2_border_color_over,
		$sub_level_2_border_style_out, "-not selected-", "-not selected-", 15, -1000000, 0, 0, -1000000, 0,
		0, -1000000, 0, 0, -1000000, 0, 0,
		"-not selected-", -1, 0, -1, 0, "-not selected-", -1000000, 0, -1000000, 0,
		-1000000, 0, -1000000, 0, -1000000, "-not selected-",
		-1, 0, -1, 0, -1, 0, -1, 0,
		"-not selected-", "-not selected-", "-not selected-", "-not selected-", 0, 0,
		0, "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-", "-not selected-");
	}
//	echo $query;
	$cnt = $bwb_dbh->exec($query);
	
	/////////////////////////////////////////////
	// Build string for menu.css file /////
	include("build_css_string.php");


	////////////////////////////////////////////////////////
	/// Write menu items to menu.css file /////////////
	//Test to see if file already exists.
	$document_root = $_SERVER['DOCUMENT_ROOT'];
	if (BWB_BASE_DIR == '')
		$userfiles = '';
	else
		$userfiles = "/" . BWB_BASE_DIR;
		
	$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
		
	if (file_exists($file_name))
	{
		$bkup_file_name = $file_name . time();
		if (!rename($file_name, $bkup_file_name))
			echo "Could not rename $file_name to $bkup_file_name.<br>";
		@chmod($bkup_file_name, 0755);
	}
	
	// Create file.
	$fh = fopen($file_name, 'x') or die("Can't create $file_name: $php_errormsg");
	$result = (fputs($fh, $css_string));
	fclose($fh) or die($php_errormsg);
	@chmod($file_name, 0755);
	
	if ($submit == "Preview")
		header("Location: preview_menu.php?suffix=$suffix&menu_type=1");
	else
		header("Location: edit_js_menu_styles.php?menu=$menu");
	
?>
